elife-article
=============

.. image:: https://travis-ci.org/elifesciences/elife-article.svg?branch=master
   :target: https://travis-ci.org/elifesciences/elife-article
   :alt: Latest Version
   
.. image:: https://coveralls.io/repos/elifesciences/elife-article/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/elifesciences/elife-article?branch=master


eLife article object
